pub fn unify<T: Config>(
nft_collection_id: T::NftCollectionId,
nft_id: T::NftId,
asset_id: AssetIdOf<T>,
beneficiary: AccountIdLookupOf<T>,
)Expand description
Burn the total issuance of the fungible asset and return (unlock) the locked NFT.
The asset is destroyed as well, unless it still has asset accounts – from touch –
or approvals, or the asset registry refuses, in which case anyone can finish the
destruction later.
The dispatch origin for this call must be Signed.
Deposit funds will be returned to asset_creator.
nft_collection_id: The ID used to identify the collection of the NFT. Is used within the context ofpallet_nfts.nft_id: The ID used to identify the NFT within the given collection. Is used within the context ofpallet_nfts.asset_id: The ID of the asset being returned and destroyed. Must match the original ID of the created asset, corresponding to the NFT. Is used within the context ofpallet_assets.beneficiary: The account that will receive the unified NFT.
Emits NftUnified event when successful.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::unify.